function analyses = SCEt_Ana_Conds(filt)
% stat_conditions_pyFR
% Holds "definitions" for contrasts. 
%
% INPUTS
% filt      the desired analysis/filter, e.g. rec
%
% The input filt will call one of the many subfunctions below, which create
% the analyses field in the params structure. The analyses field will have
% the following fields
%
% name = 'rec';             % Name of the analysis. Will be in the
%                           directory name where files are saved
% cond1 = strcat(d.rec);    % String used to filter for condition 1
% cond2 = strcat(d.nrec);   % String used to filter for condition 2
%
% The d structure is the "definition" structure which pre-sets all of the
% filtering strings. It assumes you are using Kahana-lab event structures
% and the functions inStruct and filterStruct. For an explanation of how
% these strings are applied to the event structure, please see
% Analyzing_EEG_Data in the eeg_toolbox documentation. 
%
% N. Long

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% "Definitions"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
d.rec = 'recalled == 1';
d.nrec = 'recalled == 0';

d.htem = '(abs(lag_in)==1 | abs(lag_out)==1)';
d.ltem = '(abs(lag_in)~=1 & abs(lag_out)~=1) & ~((abs(lag_in) == 0 & abs(lag_out) == 0))';

% Compile the filter you want
analyses = struct; i = 1;
filt = str2func(filt);
analyses = filt(analyses,d, i);

function analyses = HT_LT_NR(analyses,d,i)
% % High temporal, Low Temporal, Not recalled
analyses(i).name = 'HT_LT_NR';
analyses(i).cond1 = strcat(d.rec,'&',d.htem);
analyses(i).cond2 = strcat(d.rec,'&',d.ltem);
analyses(i).cond3 = strcat(d.nrec);
i = i + 1;

function analyses = rec(analyses,d,i)
% Recalled > not recalled
analyses(i).name = 'rec';
analyses(i).cond1 = strcat(d.rec);
analyses(i).cond2 = strcat(d.nrec);
i = i + 1;
