function SCEt_Figure1(params)
% Generates Figure 1 from Long & Kahana, Sucessful memory formation
% is driven by contextual encoding in the core memory network
%
% Loads behavioral data from a saved structure (created by ecog_behav) and
% extracts probability of recall (prec) and lag CRP, and calculates the temporal
% difference score (TD). Makes a figure of the lag CRP and a scatter plot of the
% correlation between TD and prec.
%
% N. Long

close all

% Get the LAG CRP.
% Extract temporal difference score, probability of recall and lag CRP
% using the get_lag_info function
[td,precs,lag_crps] = SCEt_Behav_Ana;
% Filter the LAG CRP for only the good (136) subjects.
load ~/Experiments/pyFR/indices.mat
fullInd = leftInd & montInd & techInd ;

plot(nanmean(lag_crps(fullInd,:)))
CRP = lag_crps(fullInd,:);

EB = nanstd(CRP)/sqrt(136);
errorbar(nanmean(CRP),EB,'Linewidth',2,'color','black');
box off
set(gca,'ylim',[0 .3]);
set(gca,'ytick',[0 .1 .2 .3]);
set(gca,'xtick',[1 5 7 11]);
set(gca,'xticklabel',[-5 -1 1 5]);
set(gca,'Fontsize',params.fontsize);
set(gca,'xlim',[0 12]);

% Print if desired.
if params.print
    figname = (['Lag_CRP_Ecog_N' mat2str(params.N) '.eps']);
    print(fullfile(params.figdir,figname),'-depsc2');
    convert_eps_to_pdf(params.figdir,pwd);
else
    pause
end

% Correlate TD and PREC. basic_scatter handles printing/etc.
ind = ~isnan(td) & ~isnan(precs);
x_var = td(ind&fullInd);
y_var = precs(ind&fullInd);

basic_scatter(x_var,y_var,params);
